pyDataCanvas
============

Runtime support for DataCanvas

Installation
------------

Our latest stable is always available on PyPi.

    pip install pyDataCanvas

Documentation
-------------

See also [screwjack](screwjack.readthedocs.org).

License
-------
pyDataCanvas is licensed under the Apache License, Version 2.0. See LICENSE for full license text


Kerberos Authentication (Option)
-------
* kerberosConfig: 
  > {"kdcLocation":"124.42.117.60:88","kServer":"124.42.117.60:749","kUserName":"wuhaifeng@TEST.COM","keyTabServer":"192.168.1.54","keyTabPort":18185}
* isValidate: true